@@ -72,7 +72,6 @@ outline_window_expose (GtkWidget      *widget,
                        gpointer        data)
 {
   MetaTabPopup *popup;
-  int w, h;
   TabEntry *te;  
   
   popup = data;
@@ -82,8 +81,6 @@ outline_window_expose (GtkWidget      *widget,
 
   te = popup->current_selected_entry;
   
-  gdk_window_get_size (widget->window, &w, &h);
-
   gdk_draw_rectangle (widget->window,
                       widget->style->white_gc,
                       FALSE,
@@ -842,12 +839,17 @@ meta_select_workspace_expose_event (GtkWidget      *widget,
   while (tmp != NULL)
     {
       MetaWindow *window;
+      gboolean ignoreable_sticky;
 
       window = tmp->data;
 
+      ignoreable_sticky = window->on_all_workspaces &&
+                          workspace != workspace->screen->active_workspace;
+
       if (window->skip_pager || 
           window->minimized || 
-          window->unmaps_pending)
+          window->unmaps_pending ||
+          ignoreable_sticky)
         {
           --n_windows;
         }
